@@ -3,12 +3,14 @@ import importlib
 import logging
 import os
 import re
+import signal
 import sys
 from datetime import timezone
 from urllib.parse import urlparse
 
 import dateutil.parser
 import gi
+from pip import main
 
 gi.require_version("Gst", "1.0")
 gi.require_version("GstPbutils", "1.0")
@@ -20,6 +22,7 @@ from .options import Options
 from .schema import (
     Audio,
     Container,
+    Error,
     Field,
     File,
     Info,
@@ -59,6 +62,7 @@ class Discoverer(object):
         self.quit = args.quit
         self.dir = args.dir
         self.force = args.force
+        self.signal_received = False
         schema = Schema(config)
         self.session = schema.create_session()
         # TODO Set the logging level
@@ -83,16 +87,10 @@ class Discoverer(object):
         self.discoverer.connect("finished", self.on_finished)
         self.numdiscoveries = 0
         self.discoverer.start()
-        # Iterate over the files in the directory
-        self.numdirs = 1
-        self.path.enumerate_children_async(
-            "*",
-            Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
-            0,
-            None,
-            self.on_directory_content,
-            None,
+        GLib.unix_signal_add(
+            GLib.PRIORITY_HIGH, signal.SIGUSR1, self.on_usr1_signal, signal.SIGUSR1
         )
+        self.scan_root()
 
     def _has_gst_override(self):
         # FIXME we need python3-gst-1.0 package to be installed in the virtualenv for
@@ -125,7 +123,7 @@ class Discoverer(object):
         if not exists:
             # Fill the File information
             self.add_file(basename, dirname, mtime)
-        if needs_update or self.force:
+        if needs_update or self.force or self.signal_received:
             # Start discovering
             uri = "file://{}".format(path)
             logger.debug(
@@ -158,6 +156,7 @@ class Discoverer(object):
         self.numdirs -= 1
         if not self.numdirs:
             logger.debug("No more dirs")
+            self.signal_received = False
         self.check_quit()
 
     def check_quit(self):
@@ -293,8 +292,21 @@ class Discoverer(object):
             self.discovery_done()
             return
 
-        if error:
+        if type(error) == gi.repository.GLib.GError:
             logger.error("With error {}".format(error))
+            path = urlparse(info.get_uri()).path
+            (dirname, basename) = self.rel_path(path)
+            file = self.session.query(File).filter(File.name == basename).first()
+            db_error = Error()
+            db_error.file_id = file.id
+            db_error.error_log = str(error)
+            try:
+                self.session.add(db_error)
+                self.session.commit()
+            except:
+                logger.error("Couldn't add error {} to the database".format(error))
+            finally:
+                self.session.close()
 
         path = urlparse(info.get_uri()).path
         (dirname, basename) = self.rel_path(path)
@@ -365,6 +377,27 @@ class Discoverer(object):
         enum = path.enumerate_children_finish(res)
         enum.next_files_async(1, 0, None, self.on_file_found, None)
 
+    def on_usr1_signal(self, signum):
+        if self.numdirs or self.numdiscoveries:
+            logger.debug("Currently scanning, nothing to do")
+            return
+        elif signum == signal.SIGUSR1:
+            self.signal_received = True
+            self.scan_root()
+            return True
+
+    def scan_root(self):
+        # Iterate over the files in the directory
+        self.numdirs = 1
+        self.path.enumerate_children_async(
+            "*",
+            Gio.FileQueryInfoFlags.NOFOLLOW_SYMLINKS,
+            0,
+            None,
+            self.on_directory_content,
+            None,
+        )
+
     def start(self):
         self.loop.run()
 
@@ -380,3 +413,7 @@ def run():
     config = Config(args)
     discoverer = Discoverer(config, args)
     discoverer.start()
+
+
+if __name__ == "__main__":
+    run()
